<?php
/* vim: set et ts=4 sw=4 sts=4 ai: */
// +----------------------------------------------------------------------+
// | Draw image pages. This is the heavy lifting. You *SO* don't want to  |
// | look at this, much less change it.                                   |
// +----------------------------------------------------------------------+
// | @version $Revision: 1.48 $
// +----------------------------------------------------------------------+

//----- Lookup request : "all", number, or letter that corresponds to category
$tocache = false;
if ($path == "all" && FEATURE_SHOWALL===true) {
    $category = "All";
    $tocache = true;
} else if (is_numeric($path)) {
    $category = $path;
} else if ($path == "stats") {
    $category = "Stats";
} else if ($path == "search") {
    $q = stripslashes($path_parts[2]);
    if($path_parts[3]) {
        $fields = array();
        $qfields = explode(",",$path_parts[3]);
        // This holds the part that goes in the query string, ie "title,keywords"
        $fields_query = array();
        // This holds the validated fields to be passed to getImages()
        if(is_array($qfields)) {
            foreach(array("title","keywords","file","comment","name","tripcode") as $x) {
                if(in_array($x,$qfields)) {
                    array_push($fields,$x);
                    array_push($fields_query,"$x");
                }
            }
        }
    } else {
        $fields=array("title","keywords");
    }
    $category = "Search: " . htmlspecialchars($q);
    $categories_query = $path_parts[4] ? $path_parts[4] : false;
} else if ($path == "keyword") {
    $q = stripslashes($path_parts[2]);
    $category = "Keywords: " . htmlspecialchars($q);
    $categories_query = $path_parts[3] ? $path_parts[3] : false;
} else {
    $categories = getCategories($path);
    if (is_array($categories) && count($categories)==1) {
        $category = $categories[0]["category"];
        $tocache = true;

    } else {
        // OK, can't figure out the request, kick up to root
        header("Location: " . ABSOLUTE_ROOT);
        exit;
    }
}

// Hit the cache?
if($tocache) {
    $page->setCache(FEATURE_CACHE,$path);
    $page->checkCache(__FILE__,$path);
}

$offset = ($page_num - 1)*LIMIT;
if($category=="All") {
	$count = getCount();
	$images = getImages("All",$offset);
    $page->title = "All";
} else if (is_numeric($category)) {
    $images = getImages($category,0);

    // Can't link to a reply - redirect to thread
    if($images[0]["parent"]) {
        header("Location: " . ABSOLUTE_ROOT . "/" . $images[0]["parent"] . "#i" . $category);
        exit;
    } else {
        $page->meta('<style type="text/css">.collapse { display:block }</style>');
    }
    $title = $images[0]["title"] ? $images[0]["id"] . ": " .$images[0]["title"] : $STRINGS["untitled"];
    $page->title = htmlspecialchars(stripslashes($title));
} else if($path == "search") {
    $count = getCount($path,$q,$fields,$categories_query);
    $images = getImages($path,$offset,$q,"asc",$fields,$categories_query);
    $page->title = $category;
} else if($path == "keyword") {
    $count = getCount($path,$q,false,$categories_query);
    $images = getImages($path,$offset,$q,"asc",false,$categories_query);
    $page->title = $category;
} else if($category == "Stats") {
    $count = LIMIT;
    $images = getImages("Stats",0);
    $page->title = $category;
} else {
    $count = getCount($path);
    $images = getImages($path,$offset,false,$categories[0]["sort"]);
    $title = $categories[0]["category"] . ": " . $categories[0]["description"];
    $page->title = $title;
}

if($images === false) {
    $page->fail($ERRORS["queryfail"]);
}


//----- BEGIN: PAGERS ARE A ROYAL PAIN
$num_pages = floor(($count-1)/LIMIT+1);
if ($count < ($page_num-1)*$limit) {
	$page_num = 1;
}
if ($page_num<1 or ($page_num>$num_pages && $count>0)) {
    header("Location: " . ABSOLUTE_ROOT);
    exit;
}

$start = $page_num - floor((PAGER_SIZE-1)/2);
$start = $start > 0 ? $start : 1;
$end = $start + PAGER_SIZE-1;
$end = $end > $num_pages ? $num_pages : $end;

$start = $end-$start<PAGER_SIZE-1 ? $end-PAGER_SIZE+1 : $start;
$start = $start > 0 ? $start : 1;


$pager = array("<span class=\"current\">Page $page_num of $num_pages </span>");
if(is_array($fields_query)) {
    $fields_query = implode(",",$fields_query);
} else {
    $fields_query = "";
}

if($num_pages>10 && $start!=1) {
    array_push($pager,"<a href=\"?p=1\"><span>First</span></a>");
}
if ($page_num>1) {
	array_push($pager,"<a href=\"?p=" . ($page_num-1) . "\"><span>&laquo;</span></a>");
}
for($i=$start; $i<=$end;$i++) {
	if ($i==$page_num) {
		array_push($pager,"<span class=\"current\">$i</span>");
	} else {
		array_push($pager,"<a href=\"?p=$i\"><span>$i</span></a>");
	}
}
if($page_num<$num_pages) {
	array_push($pager,"<a href=\"?p=" . ($page_num+1) . "\"><span>&raquo;</span></a>");
}
if($end<$num_pages) {
	array_push($pager,"<a href=\"?p=$num_pages\"><span>Last</span></a>");
}
$pager = implode("",$pager);
if($path == "search") {
    $replace_string = ROOT . "/$path/$q/$fields_query";
    $replace_string .= $categories_query ? "/" . $categories_query : "";
    $pager = str_replace('?p=',"$replace_string?p=",$pager);
} else if ($path == "keyword") {
    $replace_string = ROOT . "/$path/$q";
    $replace_string .= $categories_query ? "/" . $categories_query : "";
    $pager = str_replace('?p=',"$replace_string?p=",$pager);
}
//----- END: PAGERS ARE A ROYAL PAIN

//----- Scan at the images return, then look up comments for this images
//      Don't do this for searches or for stats
if($path != "stats" && $path != "search") {
    $image_set = array();
    foreach($images as $row) {
        array_push($image_set,$row["id"]);
    }
    $comments = &getComments($image_set);
    if($comments === false) {
        $page->fail($ERRORS["queryfail"]);
    }
}

// Check to see if user is admin
$tripcode = tripcode($_COOKIE["tripcode"]);
$tripcodes = explode(",",ADMINS);
$is_admin = in_array($tripcode,$tripcodes) ? true : false;
$tripcodes = explode(",",MODERATORS);
$is_moderator = in_array($tripcode,$tripcodes) ? true : false;

$tmpl = new HTML_Template_IT(TEMPLATE_DIR,array("use_preg"=>false));
$tmpl->loadTemplateFile("image.tmpl");
if(count($images)<1) {
    $tmpl->touchBlock("noposts");
} else {

    foreach($images as $row) {

        // First, the comments (inside first)
        $num_comments = 0;
        $num_images = 0;
        $total_comments = count($comments[$row["id"]]);
        if(is_array($comments[$row["id"]])) {
            foreach($comments[$row["id"]] as $crow) {
                $num_comments++;
                if(is_numeric($category) ||
                    !is_numeric(FEATURE_THREAD_TRUNCATE)  ||
                    $total_comments <= FEATURE_THREAD_TRUNCATE ||
                    ($total_comments - $num_comments < FEATURE_THREAD_TRUNCATE)) {

                    $vars = array();
                    $vars["comment_id"] = $crow["id"];
                    $vars["comment_name"] = wordwrap(htmlspecialchars(stripslashes($crow["name"])),40,"\n",1);
                    $vars["comment_tripcode"] = htmlspecialchars(stripslashes($crow["tripcode"]));
                    if(function_exists("custom_comment_format")) {
                        $vars["comment"] = custom_comment_format($crow["comment"]);
                    } else {
                        $vars["comment"] = nl2br(htmlspecialchars(stripslashes($crow["comment"])));
                    }
                    $vars["comment"] = wordwrap($vars["comment"],80," ",1);
                    $vars["comment"] = str_replace("$","&#36;",$vars["comment"]);
                    $vars["comment_timestamp"] = $crow["date"];
                    $vars["comment_date"] = date("Y-m-d H:i:s T",$crow["date"]);
                    if(is_numeric($category)) {
                        $vars["comment_delete_id"] = $crow["id"];
                        $vars["comment_delete_root"] = ROOT;
                        // Admins get to see the edit link
                        if($is_admin) {
                            $vars["comment_edit_id"] = $crow["id"];
                            $vars["comment_move_id"] = &$crow["id"];
                            $vars["comment_edit_root"] = ROOT;
                            $vars["comment_move_root"] = ROOT;
                        }
                        // Mods get to see the ban link
                        if($is_moderator) {
                            $vars["ban_ip"] = $crow["ip"];
                            $vars["comment_ban_root"] = ROOT;
                        }
                            
                    }
                    if($crow["file"]) {
                        $num_images++;
                        if($crow["animated"]=="t" || $crow["animated"]=="1") {
                            $vars["animated"] = $STRINGS["animated"];
                        }
                        $vars["ROOT"] = ROOT;
                        $vars["comment_image_id"] = $crow["id"];
                        $vars["comment_image_file"] = ereg_replace("(^[0-9]+)-","\\1/",$crow["file"]);
                        $vars["comment_image_url"] = FEATURE_COUNT_VIEWS ?
                            ROOT . "/view/" . $vars["comment_image_file"] :
                            getImageUrl($crow["id"],$crow["file"]);
                        $vars["comment_image_thumb_url"] = getImageUrl($crow["id"],$crow["file"],true);
                        $vars["comment_image_size"] = $crow["size"];
                        $vars["comment_image_resolution"] = $crow["resolution"];
                        $vars["comment_base_file"] = ereg_replace("^[0-9]+-","",$crow["file"]);
                        if(FEATURE_COUNT_VIEWS) {
                            $vars["comment_image_views"] = $crow["views"];
                        }
                    }


                    $tmpl->setCurrentBlock("comment");
                    $tmpl->setVariable($vars);
                    $tmpl->parseCurrentBlock();
               } 
            }
        }

        // Now, the posting block
        $vars = array();
        $vars["ROOT"] = ROOT;
        $vars["name"] = htmlspecialchars(stripslashes($row["name"]));
        $vars["tripcode"] = $row["tripcode"];
        $vars["date"] = date("Y-m-d H:i:s T",$row["date"]);
        $vars["timestamp"] = $row["date"];
        $vars["animated"] = ($row["animated"]=="t" || $row["animated"]=="1") ? $STRINGS["animated"] : "";
        if(function_exists("custom_comment_format")) {
            $vars["comment"] = custom_comment_format($row["comment"]);
        } else {
            $vars["comment"] = nl2br(htmlspecialchars(stripslashes($row["comment"])));
        }
        $vars["comment"] = str_replace("$","&#36;",$vars["comment"]);
        $row["title"] = htmlspecialchars(stripslashes($row["title"]));
        $row["title"] = str_replace("$","&#36;",$row["title"]);
        // If in search/stats and no parent, indicate as such
        if(($path=="search" || $path=="stats") && $row["parent"]) {
            $title = $STRINGS["reply"]; 
        } else {
            $title = $row["title"] ? $row["title"] : $STRINGS["untitled"];
        }
        $vars["title"] = $title;
        $vars["id"] = $row["id"];
        $vars["comment_parent_id"] = "cblock" . $row["id"];
        if($num_comments>0) {
            $vars["num_comments"] = $num_comments;
            $vars["num_images"] = $num_images;
            $vars["collapse_expand_id"] = "cblock" . $row["id"];
        }
        if(is_numeric(FEATURE_THREAD_TRUNCATE) && $total_comments > (int) FEATURE_THREAD_TRUNCATE && !is_numeric($category)) {
            $vars["truncate_newest"] = FEATURE_THREAD_TRUNCATE;
            $vars["truncate_total"] = $total_comments;
            $vars["truncate_id"] = $row["id"];
        }
        
        if($row["file"] == DELETED_IMAGE) {
            $vars["deleted_url"] = IMAGE_URL . "/" . DELETED_IMAGE;
        } else {
            if($row["file"]) {
                $vars["file"] = ereg_replace("(^[0-9]+)-","\\1/",$row["file"]);
                $vars["image_url"] = FEATURE_COUNT_VIEWS ?
                    ROOT . "/view/" . $vars["file"] :
                    getImageUrl($row["id"],$row["file"]);
                $vars["base_file"] = ereg_replace("^[0-9]+-","",$row["file"]);
                $vars["file_url"] = getImageUrl($row["id"],$row["file"],false);
                $vars["thumb_url"] = getImageUrl($row["id"],$row["file"],true);
                $vars["size"] = $row["size"];
                if(FEATURE_COUNT_VIEWS) {
                    $vars["views"] = $row["views"];
                }
                $vars["resolution"] = $row["resolution"];
            }
        }

        // If in detail view, some additional stuff
        $c = ereg_replace("^/(.+)/$","\\1",$row["category"]);
        $c = explode("/",$c);
        $c = "/" . implode(", /",$c);
        if(is_numeric($category)) {
            $vars["detail_categories"] = $c? $c : $STRINGS["none"];
            $vars["detail_keywords"] = $row["keywords"] ? $row["keywords"] : $STRINGS["none"];
            $vars["modify_id"] = $row["id"];
            $vars["delete_id"] = $row["id"];

            // Moderators get to see the ban link
            if($is_moderator) {
                $vars["ban_parent_ip"] = $row["ip"];
            }

            // Admins see move link
            if($is_admin) {
                $vars["move_id"] = $row["id"];
            }
        } else {
            $vars["details_id"] = $row["id"];
            if($category=="All") {
                $vars["detail_categories"] = $c? $c : $STRINGS["none"];
            }
        }


        // If not in search or stats, activate reply link
        if($path != "stats" && $path != "search") {
            $tmpl->setCurrentBlock("saged_notice");
            // If thread is sage'd, activate notice
            if(count($comments[$row["id"]])>=FEATURE_SAGE) {
                $tmpl->setVariable("saged","saged");
            } else {
                $tmpl->touchBlock("reply_link");
            }
            $tmpl->parseCurrentBlock();
        }

        $tmpl->setCurrentBlock("image_block");
        $tmpl->setVariable($vars);
        $tmpl->parseCurrentBlock();
    }
}
// Now, the content as a whole
$vars = array();
$vars["category"] = is_numeric($category) ? "#${row["id"]} $title from ${row["name"]}" : $category;
if($category == "Stats") {
    $vars["category"] = "Top " . LIMIT . " Most Viewed Images";
}
$vars["description"] = $category == "Stats" ? "" : htmlspecialchars(stripslashes($categories[0]["description"]));
if (!is_numeric($category) && count($images)>=1) {
    $vars["pager_top"] = $pager;
    $vars["pager_bottom"] = $pager;
}
if(FEATURE_RSS && $path != 'keyword' && $path != 'search' && $path != "stats" && !is_numeric($category)) {
    $vars["rss_image"] = IMAGE_URL . "/rss.png";
    if($category=="All") {
        $vars["rss_url"] = ROOT . "/rss";
    } else {
        $vars["rss_url"] = ROOT . "/rss/" . $categories[0]["abbr"] . ".rss";
    }
}
$tmpl->setVariable($vars);
$tmpl->show();
?>
