<?php
header("Content-type: text/plain");
require_once("conf.php");

// Check for convert
$convert = explode(" ",CONVERT);
$convert = $convert[0];
echo "Checking for convert ($convert) ... ";
if(is_executable($convert)) {
    echo "OK\n\n";
} else {
    echo "FAILED\n\n";
    exit;
}

// Check for identify
$identify = explode(" ",IDENTIFY);
$identify = $identify[0];
echo "Checking for identify ($identify) ... ";
if(is_executable($identify)) {
    echo "OK\n\n";
} else {
    echo "FAILED\n\n";
    exit;
}

// Check for directory permissions
foreach(array(IMAGE_DIR,THUMB_DIR) as $x) {
    echo "Checking permissions on $x ... ";
    if(is_writable($x)) {
        echo "OK\n\n";
    } else {
        echo "FAIL - COULDN'T WRITE\n\n";
        exit;
    }
}

// Check for cache dir
echo "Checking permissions on " . CACHE_DIR . " ...";
if(is_writable(CACHE_DIR)) {
	echo "OK\n\n";
} else {
	if(!@mkdir(CACHE_DIR,0700)) {
		echo "FAIL - COULDN'T WRITE. PLEASE CHECK THIS.\n\n";
	} else {
		echo "OK\n\n";
	}
}

// Check for HTML_Template_IT
echo "Checking for HTML_Template_IT ...";
require_once(INCLUDES_DIR . "/page.php");
if(is_callable(array("HTML_Template_IT","setVariable"))) {
    echo "OK\n\n";
} else {
	echo "FAIL - please check http://ochiba.x-maru.org/reqs for help\n\n";
	exit;
}

// Check for PEAR::DB
echo "Checking for PEAR::DB ...";
require_once("DB.php");
if(is_callable(array("DB","connect"))) {
	echo "OK\n\n";
} else {
	echo "FAIL - please check http://ochiba.x-maru.org/reqs for help\n\n";
	exit;
}

// Checking for database definition
echo "Checking for database definition ... ";
if(defined("DB")) {
	echo "OK\n\n";
} else {
	echo "FAIL - please edit conf.php\n\n";
	exit;
}

// Check for database connection...
echo "Checking for database connection ... ";
$db = DB::connect(DB);
if(DB::isError($db)) {
	echo "FAILED - please check connection settings (" . DB . ")\n\n";
	exit;
} else {
    echo "OK\n\n";
}

// Check for existing setup...
echo "Checking for presence of database ... ";
$sql = "select * from categories";
$result = $db->query($sql);
if(DB::isError($result)) {
    echo "OK - database doesn't exist yet\n\n";
} else {
	echo "DATABASE APPEARS TO EXIST ALREADY ... exiting ...\n\n";
	exit;
}

// Load database
echo "Installing database (" . $db->phptype . ") ... ";
switch($db->phptype) {
	case "sqlite":
	$schema = array(
		"create table bans(ip primary key, date integer, tripcode, reason)",
		"create table categories(id integer primary key,category unique,abbr unique,description,sort)",
		"create table images(id integer primary key,parent int,name,tripcode,title,file,type,animated,size,resolution,keywords,category,comment,date,ip,mtime,views integer default 0, sort int,hash)",
		"create view v_categorized as select i.id,i.parent,i.name,i.tripcode,i.title,i.file,i.type,i.animated,i.size,i.resolution,i.keywords,i.comment,i.date,i.ip,i.mtime,i.views,x.category from images i join (select id,category from images where parent is null) as x where i.parent=x.id union select id,parent,name,tripcode,title,file,type,animated,size,resolution,keywords,comment,date,ip,mtime,views,category from images where parent is null"
	);
	break;

	case "mysql":
	$schema = array(
		"CREATE TABLE bans ( ip varchar(15) NOT NULL default '', date int(11) default NULL, tripcode varchar(10) default NULL, reason text, PRIMARY KEY  (ip))",
		"CREATE TABLE categories ( id int(11) NOT NULL auto_increment, category text, abbr text NOT NULL, description text, sort varchar(4) default NULL, PRIMARY KEY  (id), UNIQUE KEY abbr (abbr(32),category(32)))",
		"CREATE TABLE images ( id int(11) NOT NULL auto_increment, parent int(11) default NULL, name text, tripcode varchar(10) default NULL, title text, file text, type varchar(4) default NULL, animated tinyint(4) default NULL, size int(11) default NULL, resolution varchar(16) default NULL, keywords text, category text, comment text, date int(11) default NULL, ip text NOT NULL, mtime int(11) default NULL, views int(11) default '0', sort float default NULL, hash text, PRIMARY KEY  (id))",
	);
	break;

	case "pgsql":
	default:
	$schema = array(
		"create table bans(ip char(15) primary key, date integer, tripcode varchar(10), reason text);",
		"create table categories(id serial not null, category text unique not null, abbr text unique not null, description text not null, sort varchar(4))",
		"create table images(id serial not null, parent int, name text, tripcode varchar(10), title text, file text, type varchar(4), animated boolean default 'f',size int, resolution varchar(16), keywords text, category text,comment text, date int, ip text not null, mtime int, views int default 0, sort float, hash text)",
		"create view v_categorized as select i.id,i.parent,i.name,i.tripcode,i.title,i.file,i.type,i.animated,i.size,i.resolution,i.keywords,i.comment,i.date,i.ip,i.mtime,i.views,x.category from images i join (select id,category from images where parent is null) as x on (i.parent=x.id) union select id,parent,name,tripcode,title,file,type,animated,size,resolution,keywords,comment,date,ip,mtime,views,category from images where parent is null",
	);
	break;

}

foreach ($schema as $line) {
	$result = $db->query($line);
	if(DB::isError($result)) {
        echo "\n\nOOPS. Error attempting '$line'.\n\n";
		echo "The error was: " . $result->getDebugInfo();
		echo "\n\nYou have some clean up to do";
        exit;
    }
}
echo "OK!!!\n\n";
echo "--> All systems go. You should now delete this file (" . __FILE__ . ")\n";
?>
